@@ -30,10 +30,8 @@
 /** Counters struct for a client's bandwidth usage (in bytes)
  */
 typedef struct _t_counters {
-	unsigned long long incoming;	/**< @brief Incoming data total*/
-	unsigned long long outgoing;	/**< @brief Outgoing data total*/
-	unsigned long long incoming_history;	/**< @brief Incoming data before nodogsplash restarted*/
-	unsigned long long outgoing_history;	/**< @brief Outgoing data before nodogsplash restarted*/
+	unsigned long long incoming;	/**< @brief Incoming data total */
+	unsigned long long outgoing;	/**< @brief Outgoing data total */
 	time_t last_updated;	/**< @brief Last update of the counters */
 } t_counters;
 
@@ -42,15 +40,15 @@ typedef struct _t_counters {
 typedef struct _t_client {
 	struct _t_client *next;	/**< @brief Pointer to the next client */
 	char *ip;				/**< @brief Client IP address */
-	char *mac;			/**< @brief Client MAC address */
-	char *token;			/**< @brief Client token */
+	char *mac;				/**< @brief Client MAC address */
+	char *token;		/**< @brief Client token */
 	unsigned int fw_connection_state;	/**< @brief Connection state in the firewall */
-	time_t added_time;		/**< @brief Time client added to list */
+	time_t session_start;	/**< @brief Time the client was authenticated */
+	time_t session_end;		/**< @brief Time until client will be deauthenticated */
 	t_counters counters;	/**< @brief Counters for input/output of the client. */
-	int attempts;			/**< @brief Number of authentication attempts */
 	int download_limit;		/**< @brief Download limit, kb/s */
 	int upload_limit;		/**< @brief Upload limit, kb/s */
-	int idx;
+	unsigned id;
 } t_client;
 
 /** @brief Get the first element of the list of connected clients
@@ -64,10 +62,16 @@ void client_list_init(void);
 int get_client_list_length();
 
 /** @brief Adds a new client to the client list */
-t_client *client_list_add_client(const char ip[]);
+t_client *client_list_add_client(const char mac[], const char ip[]);
 
-/** @brief Finds a client by its IP and MAC */
-t_client *client_list_find(const char ip[], const char mac[]);
+/** @brief Finds a client by its MAC, IP or token */
+t_client *client_list_find_by_any(const char mac[], const char ip[], const char token[]);
+
+/** @brief Finds a client by its MAC and IP */
+t_client * client_list_find(const char mac[], const char ip[]);
+
+/** @brief Finds a client by its client id */
+t_client * client_list_find_by_id(const unsigned id);
 
 /** @brief Finds a client only by its IP */
 t_client *client_list_find_by_ip(const char ip[]); /* needed by fw_iptables.c, auth.c * and ndsctl_thread.c */
@@ -78,6 +82,9 @@ t_client *client_list_find_by_mac(const char mac[]); /* needed by ndsctl_thread.
 /** @brief Finds a client by its token */
 t_client *client_list_find_by_token(const char token[]);
 
+/** @brief Reset volatile client fields */
+void client_reset(t_client *client);
+
 /** @brief Deletes a client from the client list */
 void client_list_delete(t_client *client);
 
