@@ -75,14 +75,6 @@ typedef enum {
 	/* TODO: deprecate oGatewayAddress option */
 	oGatewayAddress,
 	oGatewayPort,
-	oFasPort,
-	oFasKey,
-	oFasPath,
-	oFasRemoteIP,
-	oFasRemoteFQDN,
-	oFasURL,
-	oFasSSL,
-	oFasSecureEnabled,
 	oHTTPDMaxConn,
 	oWebRoot,
 	oSplashPage,
@@ -131,14 +123,6 @@ static const struct {
 	/* TODO: remove/deprecate gatewayaddress keyword */
 	{ "gatewayaddress", oGatewayAddress },
 	{ "gatewayport", oGatewayPort },
-	{ "fasport", oFasPort },
-	{ "faskey", oFasKey },
-	{ "fasremoteip", oFasRemoteIP },
-	{ "fasremotefqdn", oFasRemoteFQDN },
-	{ "fasurl", oFasURL },
-	{ "fasssl", oFasSSL },
-	{ "fas_secure_enabled", oFasSecureEnabled },
-	{ "faspath", oFasPath },
 	{ "webroot", oWebRoot },
 	{ "splashpage", oSplashPage },
 	{ "statuspage", oStatusPage },
@@ -208,14 +192,6 @@ config_init(void)
 	config.gw_address = NULL;
 	config.gw_ip = NULL;
 	config.gw_port = DEFAULT_GATEWAYPORT;
-	config.fas_port = DEFAULT_FASPORT;
-	config.fas_key = NULL;
-	config.fas_secure_enabled = DEFAULT_FAS_SECURE_ENABLED;
-	config.fas_remoteip = NULL;
-	config.fas_remotefqdn = NULL;
-	config.fas_url = NULL;
-	config.fas_ssl = NULL;
-	config.fas_path = DEFAULT_FASPATH;
 	config.webroot = safe_strdup(DEFAULT_WEBROOT);
 	config.splashpage = safe_strdup(DEFAULT_SPLASHPAGE);
 	config.statuspage = safe_strdup(DEFAULT_STATUSPAGE);
@@ -681,13 +657,6 @@ config_read(const char *filename)
 	char line[MAX_BUF], *s, *p1, *p2;
 	int linenum = 0, opcode, value;
 	struct stat sb;
-	char lockfile[] = "/tmp/ndsctl.lock";
-
-	//Remove ndsctl lock file if it exists
-	if (fd = fopen(lockfile, "r")) {
-		fclose(fd);
-		remove(lockfile);
-	}
 
 	debug(LOG_INFO, "Reading configuration file '%s'", filename);
 
@@ -780,32 +749,6 @@ config_read(const char *filename)
 				exit(1);
 			}
 			break;
-		case oFasPort:
-			if (sscanf(p1, "%u", &config.fas_port) < 1) {
-				debug(LOG_ERR, "Bad arg %s to option %s on line %d in %s", p1, s, linenum, filename);
-				debug(LOG_ERR, "Exiting...");
-				exit(1);
-			}
-			break;
-		case oFasSecureEnabled:
-			if (sscanf(p1, "%d", &config.fas_secure_enabled) < 1) {
-				debug(LOG_ERR, "Bad arg %s to option %s on line %d in %s", p1, s, linenum, filename);
-				debug(LOG_ERR, "Exiting...");
-				exit(1);
-			}
-			break;
-		case oFasPath:
-			config.fas_path = safe_strdup(p1);
-			break;
-		case oFasKey:
-			config.fas_key = safe_strdup(p1);
-			break;
-		case oFasRemoteIP:
-			config.fas_remoteip = safe_strdup(p1);
-			break;
-		case oFasRemoteFQDN:
-			config.fas_remotefqdn = safe_strdup(p1);
-			break;
 		case oBinAuth:
 			config.binauth = safe_strdup(p1);
 			if (!((stat(p1, &sb) == 0) && S_ISREG(sb.st_mode) && (sb.st_mode & S_IXUSR))) {
@@ -1023,8 +966,9 @@ int add_to_trusted_mac_list(const char possiblemac[])
 
 	/* check for valid format */
 	if (!check_mac_format(possiblemac)) {
-		debug(LOG_NOTICE, "[%s] not a valid MAC address to trust", possiblemac);
-		return -1;
+		debug(LOG_WARNING, "[%s] is not a valid MAC address", possiblemac);
+		debug(LOG_WARNING, "[%s]  - please remove from trustedmac list in config file", possiblemac);
+		return 1;
 	}
 
 	sscanf(possiblemac, "%17[A-Fa-f0-9:]", mac);
