@@ -29,7 +29,7 @@
 #ifndef _CONF_H_
 #define _CONF_H_
 
-#define VERSION "4.0.2"
+#define VERSION "3.3.3-beta"
 
 /*@{*/
 /** Defines */
@@ -54,10 +54,6 @@
 #define DEFAULT_GATEWAY_IPRANGE "0.0.0.0/0"
 #define DEFAULT_GATEWAYNAME "NoDogSplash"
 #define DEFAULT_GATEWAYPORT 2050
-#define DEFAULT_FASPORT 0
-#define DEFAULT_FAS_SECURE_ENABLED 1
-#define DEFAULT_FASPATH "/"
-#define DEFAULT_REMOTE_AUTH_PORT 80
 #define DEFAULT_CHECKINTERVAL 30
 #define DEFAULT_SESSION_TIMEOUT 0
 #define DEFAULT_PREAUTH_IDLE_TIMEOUT 10
@@ -152,14 +148,6 @@ typedef struct {
 	char *gw_address;		/**< @brief Internal IP with port for our web server */
 	char *gw_mac;			/**< @brief MAC address of the interface we manage */
 	unsigned int gw_port;		/**< @brief Port the webserver will run on */
-	unsigned int fas_port;		/**< @brief Port the fas server will run on */
-	int fas_secure_enabled;		/**< @brief Enable Secure FAS */
-	char *fas_path;			/**< @brief Path to forward authentication page of FAS */
-	char *fas_key;			/**< @brief AES key for FAS */
-	char *fas_remoteip;		/**< @brief IP addess of a remote FAS */
-	char *fas_remotefqdn;		/**< @brief FQDN of a remote FAS */
-	char *fas_url;			/**< @brief URL of a remote FAS */
-	char *fas_ssl;			/**< @brief SSL provider for FAS */
 	char *webroot;			/**< @brief Directory containing splash pages, etc. */
 	char *splashpage;		/**< @brief Name of main splash page */
 	char *statuspage;		/**< @brief Name of info status page */
