@@ -369,8 +369,6 @@ iptables_fw_init(void)
 	char *gw_address = NULL;
 	char *gw_iprange = NULL;
 	int gw_port = 0;
-	char *fas_remoteip = NULL;
-	int fas_port = 0;
 	int traffic_control;
 	int set_mss, mss_value;
 	t_MAC *pt;
@@ -396,11 +394,6 @@ iptables_fw_init(void)
 		ICMP_TYPE = "icmp";
 	}
 	
-	if (config->fas_port) {
-		fas_remoteip = safe_strdup(config->fas_remoteip);    /* must free */
-		fas_port = config->fas_port;
-	}
-
 	gw_address = safe_strdup(config->gw_address);    /* must free */
 	gw_iprange = safe_strdup(config->gw_iprange);    /* must free */
 	gw_port = config->gw_port;
@@ -520,11 +513,6 @@ iptables_fw_init(void)
 		// CHAIN_OUTGOING, append the "preauthenticated-users" ruleset
 		rc |= _iptables_append_ruleset("nat", "preauthenticated-users", CHAIN_OUTGOING);
 
-		// Allow access to remote FAS - CHAIN_OUTGOING and CHAIN_TO_INTERNET packets for remote FAS, ACCEPT
-		if (fas_port && strcmp(fas_remoteip, gw_ip)) {
-			rc |= iptables_do_command("-t nat -A " CHAIN_OUTGOING " -p tcp --destination %s --dport %d -j ACCEPT", fas_remoteip, fas_port);
-		}
-
 		// CHAIN_OUTGOING, packets for tcp port 80, redirect to gw_port on primary address for the iface
 		rc |= iptables_do_command("-t nat -A " CHAIN_OUTGOING " -p tcp --dport 80 -j DNAT --to-destination %s", gw_address);
 		// CHAIN_OUTGOING, other packets ACCEPT
@@ -567,11 +555,6 @@ iptables_fw_init(void)
 	// CHAIN_TO_ROUTER, packets to HTTP listening on gw_port on router ACCEPT
 	rc |= iptables_do_command("-t filter -A " CHAIN_TO_ROUTER " -p tcp --dport %d -j ACCEPT", gw_port);
 
-	// CHAIN_TO_ROUTER, packets to HTTP listening on fas_port on router ACCEPT
-	if (fas_port && !strcmp(fas_remoteip, gw_ip)) {
-		rc |= iptables_do_command("-t filter -A " CHAIN_TO_ROUTER " -p tcp --dport %d -j ACCEPT", fas_port);
-	}
-
 	// CHAIN_TO_ROUTER, packets marked TRUSTED:
 
 	/* if trusted-users-to-router ruleset is empty:
@@ -631,11 +614,6 @@ iptables_fw_init(void)
 	}
 
 
-	// Allow access to remote FAS - CHAIN_OUTGOING and CHAIN_TO_INTERNET packets for remote FAS, ACCEPT
-	if (fas_port && strcmp(fas_remoteip, gw_ip)) {
-		rc |= iptables_do_command("-t filter -A " CHAIN_TO_INTERNET " -p tcp --destination %s --dport %d -j ACCEPT", fas_remoteip, fas_port);
-	}
-
 	/* CHAIN_TO_INTERNET, packets marked TRUSTED: */
 
 	/* if trusted-users ruleset is empty:
@@ -699,7 +677,6 @@ iptables_fw_init(void)
 	free(gw_iprange);
 	free(gw_ip);
 	free(gw_address);
-	free(fas_remoteip);
 
 	return rc;
 }
@@ -1002,12 +979,15 @@ iptables_fw_counters_update(void)
 	config = config_get_config();
 	af = config->ip6 ? AF_INET6 : AF_INET;
 
+	LOCK_CLIENT_LIST();
+
 	/* Look for outgoing traffic of authenticated clients. */
 	safe_asprintf(&script, "%s %s", "iptables", "-v -n -x -t mangle -L " CHAIN_OUTGOING);
 	output = popen(script, "r");
 	free(script);
 	if (!output) {
 		debug(LOG_ERR, "popen(): %s", strerror(errno));
+		UNLOCK_CLIENT_LIST();
 		return -1;
 	}
 
@@ -1026,7 +1006,6 @@ iptables_fw_counters_update(void)
 				continue;
 			}
 			debug(LOG_DEBUG, "Read outgoing traffic for %s: Bytes=%llu", ip, counter);
-			LOCK_CLIENT_LIST();
 			if ((p1 = client_list_find_by_ip(ip))) {
 				if (p1->counters.outgoing < counter) {
 					p1->counters.outgoing = counter;
@@ -1036,7 +1015,6 @@ iptables_fw_counters_update(void)
 			} else {
 				debug(LOG_WARNING, "Could not find %s in client list", ip);
 			}
-			UNLOCK_CLIENT_LIST();
 		}
 	}
 	pclose(output);
@@ -1047,6 +1025,7 @@ iptables_fw_counters_update(void)
 	free(script);
 	if (!output) {
 		debug(LOG_ERR, "popen(): %s", strerror(errno));
+		UNLOCK_CLIENT_LIST();
 		return -1;
 	}
 
@@ -1065,7 +1044,6 @@ iptables_fw_counters_update(void)
 				continue;
 			}
 			debug(LOG_DEBUG, "Read incoming traffic for %s: Bytes=%llu", ip, counter);
-			LOCK_CLIENT_LIST();
 			if ((p1 = client_list_find_by_ip(ip))) {
 				if (p1->counters.incoming < counter) {
 					p1->counters.incoming = counter;
@@ -1074,10 +1052,10 @@ iptables_fw_counters_update(void)
 			} else {
 				debug(LOG_WARNING, "Could not find %s in client list", ip);
 			}
-			UNLOCK_CLIENT_LIST();
 		}
 	}
 	pclose(output);
+	UNLOCK_CLIENT_LIST();
 
 	return 0;
 }
