@@ -27,7 +27,6 @@
 #ifndef _FW_IPTABLES_H_
 #define _FW_IPTABLES_H_
 
-#include "firewall.h"
 #include "auth.h"
 #include "client_list.h"
 
@@ -45,6 +44,15 @@
 #define CHAIN_TRUSTED    "ndsTRU"
 /*@}*/
 
+
+/** Used to mark packets, and characterize client state.  Unmarked packets are considered 'preauthenticated' */
+extern unsigned int  FW_MARK_PREAUTHENTICATED; /**< @brief 0: Actually not used as a packet mark */
+extern unsigned int  FW_MARK_AUTHENTICATED;    /**< @brief The client is authenticated */
+extern unsigned int  FW_MARK_BLOCKED;          /**< @brief The client is blocked */
+extern unsigned int  FW_MARK_TRUSTED;          /**< @brief The client is trusted */
+extern unsigned int  FW_MARK_MASK;             /**< @brief Iptables mask: bitwise or of the others */
+
+
 /** @brief Initialize the firewall */
 int iptables_fw_init(void);
 
@@ -55,7 +63,8 @@ int iptables_fw_destroy(void);
 int iptables_fw_destroy_mention( const char table[], const char chain[], const char mention[]);
 
 /** @brief Define the access of a specific client */
-int iptables_fw_access(t_authaction action, t_client *client);
+int iptables_fw_authenticate(t_client *client);
+int iptables_fw_deauthenticate(t_client *client);
 
 /** @brief Return the total download usage in bytes */
 unsigned long long int iptables_fw_total_download();
@@ -66,6 +75,9 @@ unsigned long long int iptables_fw_total_upload();
 /** @brief All counters in the client list */
 int iptables_fw_counters_update(void);
 
+/** @brief Return a string representing a connection state */
+const char *fw_connection_state_as_string(int mark);
+
 /** @brief Fork an iptables command */
 int iptables_do_command(const char format[], ...);
 
