@@ -60,13 +60,12 @@ static int get_host_value_callback(void *cls, enum MHD_ValueKind kind, const cha
 static int serve_file(struct MHD_Connection *connection, t_client *client, const char *url);
 static int show_splashpage(struct MHD_Connection *connection, t_client *client);
 static int show_statuspage(struct MHD_Connection *connection, t_client *client);
-static int show_preauthpage(struct MHD_Connection *connection, const char *query);
 static int encode_and_redirect_to_splashpage(struct MHD_Connection *connection, const char *originurl, const char *querystr);
 static int redirect_to_splashpage(struct MHD_Connection *connection, t_client *client, const char *host, const char *url);
 static int send_error(struct MHD_Connection *connection, int error);
 static int send_redirect_temp(struct MHD_Connection *connection, const char *url);
 static int send_refresh(struct MHD_Connection *connection);
-static int is_foreign_hosts(struct MHD_Connection *connection, const char *host);
+static int is_foreign_hosts(const char *host);
 static int is_splashpage(const char *host, const char *url);
 static int get_query(struct MHD_Connection *connection, char **collect_query, const char *separator);
 static const char *get_redirect_url(struct MHD_Connection *connection);
@@ -146,7 +145,7 @@ static int counter_iterator(void *cls, enum MHD_ValueKind kind, const char *key,
 	return MHD_YES;
 }
 
-static int is_foreign_hosts(struct MHD_Connection *connection, const char *host)
+static int is_foreign_hosts(const char *host)
 {
 	char our_host[MAX_HOSTPORTLEN];
 	s_config *config = config_get_config();
@@ -184,7 +183,7 @@ static int is_splashpage(const char *host, const char *url)
 	} else {
 		/* hostname give - check if it's our hostname */
 
-		if (strcmp(host, our_host)) {
+		if (is_foreign_hosts(host)) {
 			/* hostname isn't ours */
 			return 0;
 		}
@@ -499,14 +498,12 @@ static int authenticated(struct MHD_Connection *connection,
 	s_config *config = config_get_config();
 	const char *host = NULL;
 	char redirect_to_us[128];
-	char *fasurl = NULL;
-	int ret;
 
 	MHD_get_connection_values(connection, MHD_HEADER_KIND, get_host_value_callback, &host);
 
-	/* check if this is a late request, meaning the user tries to get the internet, but ended up here,
+	/* check if this is an late request meaning the user tries to get the internet, but ended up here,
 	 * because the iptables rule came too late */
-	if (is_foreign_hosts(connection, host)) {
+	if (is_foreign_hosts(host)) {
 		/* might happen if the firewall rule isn't yet installed */
 		return send_refresh(connection);
 	}
@@ -518,36 +515,11 @@ static int authenticated(struct MHD_Connection *connection,
 	}
 
 	if (check_authdir_match(url, config->authdir)) {
-		if (config->fas_port && !config->preauth) {
-			safe_asprintf(&fasurl, "%s?clientip=%s&gatewayname=%s&status=authenticated",
-				config->fas_url, client->ip, config->gw_name);
-			debug(LOG_DEBUG, "fasurl %s", fasurl);
-			ret = send_redirect_temp(connection, fasurl);
-			free(fasurl);
-			return ret;
-		} else if (config->fas_port && config->preauth) {
-			safe_asprintf(&fasurl, "?clientip=%s%sgatewayname=%s%sstatus=authenticated",
-				client->ip, QUERYSEPARATOR, config->gw_name, QUERYSEPARATOR);
-			debug(LOG_DEBUG, "fasurl %s", fasurl);
-			ret = show_preauthpage(connection, fasurl);
-			free(fasurl);
-			return ret;	
-		} else {
-			return show_statuspage(connection, client);
-		}
+		return show_statuspage(connection, client);
 	}
 
 	if (check_authdir_match(url, config->preauthdir)) {
-		if (config->fas_port) {
-			safe_asprintf(&fasurl, "?clientip=%s&gatewayname=%s&status=authenticated",
-				client->ip, config->gw_name);
-			debug(LOG_DEBUG, "fasurl %s", fasurl);
-			ret = show_preauthpage(connection, fasurl);
-			free(fasurl);
-			return ret;
-		} else {
-			return show_statuspage(connection, client);
-		}
+		return show_statuspage(connection, client);
 	}
 
 	/* user doesn't want the splashpage or tried to auth itself */
@@ -612,7 +584,6 @@ static int preauthenticated(struct MHD_Connection *connection,
 	char *querystr = NULL;
 	char query_str[QUERYMAXLEN] = {0};
 	char *query = query_str;
-	char portstr[MAX_HOSTPORTLEN] = {0};
 
 	int ret;
 	s_config *config = config_get_config();
@@ -637,27 +608,8 @@ static int preauthenticated(struct MHD_Connection *connection,
 	debug(LOG_DEBUG, "Preauthenticated - Gateway Address is [ %s ]", config->gw_address);
 	debug(LOG_DEBUG, "Preauthenticated - Gateway Port is [ %u ]", config->gw_port);
 
-	/* check if this is an attempt to directly access the basic splash page when FAS is enabled  */
-	if (config->fas_port) {
-		snprintf(portstr, MAX_HOSTPORTLEN, ":%u", config->gw_port);
-
-		debug(LOG_DEBUG, "Preauthenticated - FAS is enabled");
-		debug(LOG_DEBUG, "Preauthenticated - NDS port ID is [ %s ]", portstr);
-		debug(LOG_DEBUG, "Preauthenticated - NDS port ID search result is [ %s ]", strstr(host, portstr));
-
-		if (check_authdir_match(url, config->authdir) || strstr(host, "/splash.css") == NULL) {
-			debug(LOG_DEBUG, "Preauthenticated - splash.css or authdir detected");
-		} else {
-			if (strstr(host, portstr) != NULL) {
-				debug(LOG_DEBUG, "Preauthenticated -  403 Direct Access Fobidden");
-				ret = send_error(connection, 403);
-				return ret;
-			}
-		}
-	}
-
 	/* check if this is a redirect query with a foreign host as target */
-	if (is_foreign_hosts(connection, host)) {
+	if (is_foreign_hosts(host)) {
 		return redirect_to_splashpage(connection, client, host, url);
 	}
 
@@ -701,61 +653,24 @@ static int preauthenticated(struct MHD_Connection *connection,
  */
 static int encode_and_redirect_to_splashpage(struct MHD_Connection *connection, const char *originurl, const char *querystr)
 {
-	char msg[QUERYMAXLEN] = {0};
 	char *splashpageurl = NULL;
-	char *phpcmd = NULL;
+	char encoded[QUERYMAXLEN] = {0};
 	s_config *config;
 	int ret;
 
 	config = config_get_config();
 
-	if (config->fas_port) {
-		// Generate secure query string or authaction url
-		// Note: config->fas_path contains a leading / as it is the path from the FAS web root.
-		if (config->fas_secure_enabled == 0) {
-			safe_asprintf(&splashpageurl, "%s?authaction=http://%s/%s/%s&redir=%s",
-				config->fas_url, config->gw_address, config->authdir, querystr, originurl);
-		} else if (config->fas_secure_enabled == 1) {
-			safe_asprintf(&splashpageurl, "%s%s&redir=%s",
-				config->fas_url, querystr, originurl);
-		} else if (config->fas_secure_enabled == 2) {
-			safe_asprintf(&phpcmd,
-				"echo '<?php \n"
-				"$key=\"%s\";\n"
-				"$string=\"%s\";\n"
-				"$cipher=\"aes-256-cbc\";\n"
-
-				"if (in_array($cipher, openssl_get_cipher_methods())) {\n"
-					"$secret_iv = base64_encode(openssl_random_pseudo_bytes(\"8\"));\n"
-					"$iv = substr(openssl_digest($secret_iv, \"sha256\"), 0, 16 );\n"
-					"$string = base64_encode( openssl_encrypt( $string, $cipher, $key, 0, $iv ) );\n"
-					"echo \"?fas=\".$string.\"&iv=\".$iv;\n"
-				"}\n"
-				" ?>' "
-				" | %s\n",
-				config->fas_key, querystr, config->fas_ssl);
-
-			debug(LOG_DEBUG, "phpcmd: %s", phpcmd);
-
-			if (execute_ret_url_encoded(msg, sizeof(msg) - 1, phpcmd) == 0) {
-				safe_asprintf(&splashpageurl, "%s%s",
-					config->fas_url, msg);
-				debug(LOG_DEBUG, "Encrypted query string=%s\n", msg);
-			} else {
-				safe_asprintf(&splashpageurl, "%s?redir=%s",
-					config->fas_url, originurl);
-				debug(LOG_ERR, "Error encrypting query string. %s", msg);
-			}
-			free(phpcmd);
+	if (originurl) {
+		if (uh_urlencode(encoded, sizeof(encoded), originurl, strlen(originurl)) == -1) {
+			debug(LOG_WARNING, "could not encode url");
 		} else {
-			safe_asprintf(&splashpageurl, "%s%s&redir=%s",
-				config->fas_url, querystr, originurl);
+			debug(LOG_DEBUG, "originurl: %s", originurl);
 		}
-	} else {
-		safe_asprintf(&splashpageurl, "http://%s/%s?redir=%s",
-			config->gw_address, config->splashpage, originurl);
 	}
 
+	safe_asprintf(&splashpageurl, "http://%s/%s?redir=%s",
+			config->gw_address, config->splashpage, encoded);
+
 	debug(LOG_DEBUG, "splashpageurl: %s", splashpageurl);
 
 	ret = send_redirect_temp(connection, splashpageurl);
@@ -773,8 +688,7 @@ static int encode_and_redirect_to_splashpage(struct MHD_Connection *connection,
  */
 static int redirect_to_splashpage(struct MHD_Connection *connection, t_client *client, const char *host, const char *url)
 {
-	char *originurl_raw = NULL;
-	char originurl[QUERYMAXLEN] = {0};
+	char *originurl = NULL;
 	char query_str[QUERYMAXLEN] = {0};
 	char *query = query_str;
 	int ret = 0;
@@ -790,35 +704,11 @@ static int redirect_to_splashpage(struct MHD_Connection *connection, t_client *c
 	}
 
 	debug(LOG_DEBUG, "Query string is [ %s ]", query);
-	safe_asprintf(&originurl_raw, "http://%s%s%s", host, url, query);
-
-	if (uh_urlencode(originurl, sizeof(originurl), originurl_raw, strlen(originurl_raw)) == -1) {
-		debug(LOG_WARNING, "could not encode url");
-	} else {
-		debug(LOG_DEBUG, "originurl: %s", originurl);
-	}
-
-
-	if (config->fas_secure_enabled == 0) {
-		safe_asprintf(&querystr, "?clientip=%s&gatewayname=%s&tok=%s", client->ip, config->gw_name, client->token);
-	} else if (config->fas_secure_enabled == 1) {
-		safe_asprintf(&querystr, "?clientip=%s&gatewayname=%s", client->ip, config->gw_name);
-	} else if (config->fas_secure_enabled == 2) {
-		safe_asprintf(&querystr,
-			"clientip=%s%sclientmac=%s%sgatewayname=%s%stok=%s%sgatewayaddress=%s%sauthdir=%s%soriginurl=%s",
-			client->ip, QUERYSEPARATOR,
-			client->mac, QUERYSEPARATOR,
-			config->gw_name, QUERYSEPARATOR,
-			client->token, QUERYSEPARATOR,
-			config->gw_address, QUERYSEPARATOR,
-			config->authdir, QUERYSEPARATOR,
-			originurl);
-	} else {
-		safe_asprintf(&querystr, "?clientip=%s&gatewayname=%s", client->ip, config->gw_name);
-	}
 
+	safe_asprintf(&querystr, "?clientip=%s&gatewayname=%s", client->ip, config->gw_name);
+	safe_asprintf(&originurl, "http://%s%s%s", host, url, query);
 	ret = encode_and_redirect_to_splashpage(connection, originurl, querystr);
-	free(originurl_raw);
+	free(originurl);
 	free(querystr);
 	return ret;
 }
