@@ -5,6 +5,10 @@
 
 struct MHD_Connection;
 
+/** @brief Get an IP's MAC address from the ARP cache.*/
+int arp_get(char mac_addr[18], const char req_ip[]);
+
+
 int libmicrohttpd_cb (void *cls,
 					struct MHD_Connection *connection,
 					const char *url,
