@@ -147,7 +147,7 @@ int execute(const char fmt[], ...)
 
 int execute_ret(char* msg, int msg_len, const char fmt[], ...)
 {
-	char cmd[QUERYMAXLEN];
+	char cmd[512];
 	va_list vlist;
 	int rc;
 
@@ -163,15 +163,6 @@ int execute_ret(char* msg, int msg_len, const char fmt[], ...)
 	return _execute_ret(msg, msg_len, cmd);
 }
 
-// Warning: Any client originated portion of the cmd string must be url encoded before calling this function.
-// It may not be desired to url encode the entire cmd string,
-// so it is our responsibility to encode the relevant parts (eg the clients original request url) before calling.
-int execute_ret_url_encoded(char* msg, int msg_len, const char *cmd)
-{
-	return _execute_ret(msg, msg_len, cmd);
-}
-
-
 char *
 get_iface_ip(const char ifname[], int ip6)
 {
@@ -426,17 +417,13 @@ ndsctl_status(FILE *fp)
 		fprintf(fp, "Preauth: Disabled\n");
 	}
 
-	if (config->fas_port) {
-		fprintf(fp, "FAS: Secure Level %u, URL: %s\n",
-			config->fas_secure_enabled,
-			config->fas_url);
-	} else {
-		fprintf(fp, "FAS: Disabled\n");
-	}
-
 	fprintf(fp, "Client Check Interval: %ds\n", config->checkinterval);
-	fprintf(fp, "Preauth Idle Timeout: %dm\n", config->preauth_idle_timeout);
-	fprintf(fp, "Auth Idle Timeout: %dm\n", config->auth_idle_timeout);
+	format_duration(0, config->preauth_idle_timeout * 60, durationbuf);
+	fprintf(fp, "Preauth Idle Timeout: %sm\n", durationbuf);
+	format_duration(0, config->auth_idle_timeout * 60, durationbuf);
+	fprintf(fp, "Auth Idle Timeout: %s\n", durationbuf);
+	format_duration(0, config->session_timeout * 60, durationbuf);
+	fprintf(fp, "Session Timeout: %s\n", durationbuf);
 
 	if (config->redirectURL) {
 		fprintf(fp, "Redirect URL: %s\n", config->redirectURL);
@@ -628,15 +615,15 @@ ndsctl_json_client(FILE *fp, const t_client *client, time_t now)
 	unsigned long int durationsecs;
 	unsigned long long int download_bytes, upload_bytes;
 
-	fprintf(fp, "\"id\":\"%d\",\n", client->id);
+	fprintf(fp, "\"id\":%d,\n", client->id);
 	fprintf(fp, "\"ip\":\"%s\",\n", client->ip);
 	fprintf(fp, "\"mac\":\"%s\",\n", client->mac);
-	fprintf(fp, "\"added\":\"%lld\",\n", (long long) client->session_start);
-	fprintf(fp, "\"active\":\"%lld\",\n", (long long) client->counters.last_updated);
+	fprintf(fp, "\"added\":%lld,\n", (long long) client->session_start);
+	fprintf(fp, "\"active\":%lld,\n", (long long) client->counters.last_updated);
 	if (client->session_start) {
-		fprintf(fp, "\"duration\":\"%lu\",\n", now - client->session_start);
+		fprintf(fp, "\"duration\":%lu,\n", now - client->session_start);
 	} else {
-		fprintf(fp, "\"duration\":\"%lu\",\n", 0ul);
+		fprintf(fp, "\"duration\":%lu,\n", 0ul);
 	}
 	fprintf(fp, "\"token\":\"%s\",\n", client->token ? client->token : "none");
 	fprintf(fp, "\"state\":\"%s\",\n", fw_connection_state_as_string(client->fw_connection_state));
@@ -645,10 +632,10 @@ ndsctl_json_client(FILE *fp, const t_client *client, time_t now)
 	download_bytes = client->counters.incoming;
 	upload_bytes = client->counters.outgoing;
 
-	fprintf(fp, "\"downloaded\":\"%llu\",\n", download_bytes / 1000);
-	fprintf(fp, "\"avg_down_speed\":\"%.2f\",\n", ((double)download_bytes) / 125 / durationsecs);
-	fprintf(fp, "\"uploaded\":\"%llu\",\n", upload_bytes / 1000);
-	fprintf(fp, "\"avg_up_speed\":\"%.2f\"\n", ((double)upload_bytes)/ 125 / durationsecs);
+	fprintf(fp, "\"downloaded\":%llu,\n", download_bytes / 1000);
+	fprintf(fp, "\"avg_down_speed\":%.2f,\n", ((double)download_bytes) / 125 / durationsecs);
+	fprintf(fp, "\"uploaded\":%llu,\n", upload_bytes / 1000);
+	fprintf(fp, "\"avg_up_speed\":%.2f\n", ((double)upload_bytes)/ 125 / durationsecs);
 }
 
 static void
@@ -690,7 +677,7 @@ ndsctl_json_all(FILE *fp)
 
 	LOCK_CLIENT_LIST();
 
-	fprintf(fp, "{\n\"client_list_length\": \"%d\",\n", get_client_list_length());
+	fprintf(fp, "{\n\"client_length\": %d,\n", get_client_list_length());
 
 	client = client_get_first_client();
 
